<?php

class DispletRetsIdxLoad extends DispletRetsIdxPlugin{
	public function enqueue(){
		include_once(ABSPATH . 'wp-admin/includes/plugin.php');
		self::enqueue_css('displet-rets-idx-styles.css');
		self::enqueue_js('displet-rets-idx-scripts.js', array('jquery', 'jquery-ui-core', 'jquery-ui-widget', 'jquery-ui-datepicker'));
	}

	public function enqueue_admin(){		
		self::enqueue_css('displet-rets-idx-admin-styles.css');
		self::enqueue_js('displet-rets-idx-admin-scripts.js', array('jquery', 'jquery-ui-core', 'jquery-ui-dialog', 'jquery-ui-tabs', 'admin-widgets'));
	}

	public function enqueue_admin_settings(){
		self::enqueue_js('displet-rets-idx-photo-upload.js', array('jquery', 'media-upload', 'thickbox'));
		wp_enqueue_style('thickbox');
	}

	public function echo_js_vars_from_options(){
		$model['options'] = DispletRetsIdxSettings::get_option();
		echo self::get_template('displet-javascript-variables.php', $model);
	}

	public function echo_admin_js_vars_from_options(){
		$model['options'] = DispletRetsIdxSettings::get_option();
		echo self::get_template('displet-admin-javascript-variables.php', $model);
	}

	public function enqueue_css($stylesheet) {
		$slug = basename($stylesheet, '.css');
		$theme_dir = get_stylesheet_directory();
		if (file_exists($theme_dir . '/' . $stylesheet)) {
			$theme_url = get_stylesheet_directory_uri();
			$stylesheet_url = $theme_url . '/' . $stylesheet;
		}
		else if (file_exists(ABSPATH . 'wp-content/plugins/displet-pro-custom/' . $stylesheet) && is_plugin_active('displet-pro-custom/displet-pro-custom.php')) {
			$stylesheet_url = plugins_url('displet-pro-custom/' . $stylesheet);
		}
		else{
			$stylesheet_url = plugins_url('displetreader-wordpress-plugin/css/' . $stylesheet);
		}
		wp_enqueue_style($slug, $stylesheet_url, false, parent::$plugin_version);
	}
	
	public function enqueue_js($script, $dependencies = array()) {
		$slug = basename($script, '.js');
		$theme_dir = get_stylesheet_directory();
		if (file_exists($theme_dir . '/' . $script)) {
			$theme_url = get_stylesheet_directory_uri();
			$script_url = $theme_url . '/' . $script;
		}
		else if (file_exists(ABSPATH . 'wp-content/plugins/displet-pro-custom/' . $script) && is_plugin_active('displet-pro-custom/displet-pro-custom.php')) {
			$script_url = plugins_url('displet-pro-custom/' . $script);
		}
		else{
			$script_url = plugins_url('displetreader-wordpress-plugin/js/' . $script);
		}
		wp_enqueue_script($slug, $script_url, $dependencies, parent::$plugin_version);
	}

	public function get_template($name, &$model) {
		$theme_dir = get_stylesheet_directory();
		if (file_exists($theme_dir . '/' . $name)) {
			$template_path = $theme_dir . '/' . $name;
		}
		else if (file_exists(ABSPATH . 'wp-content/plugins/displet-pro-custom/' . $name) && is_plugin_active('displet-pro-custom/displet-pro-custom.php')) {
			$template_path = ABSPATH . 'wp-content/plugins/displet-pro-custom/' . $name;
		}
		else{
			$template_path = dirname(__FILE__) . '/templates/' . $name;
		}
		return self::_render($template_path, $model);
	}

	public function get_admin_template($name, &$model) {
		return self::_render(dirname( __FILE__ ) . '/templates/admin/' . $name, $model);
	}
	
	public static function draw_admin_template($name, &$model, $model_alias = false) {
		echo self::get_admin_template($name, $model, $model_alias);
	}

	protected static function _render($path, &$model) {
		if (file_exists($path)) {
			ob_start();
			include $path;
			$output = ob_get_contents();
			ob_end_clean();
			return trim($output);
		}
	}
}

add_action('wp_enqueue_scripts', array('DispletRetsIdxLoad', 'enqueue'));
add_action('admin_enqueue_scripts', array('DispletRetsIdxLoad', 'enqueue_admin'));
add_action('wp_head', array('DispletRetsIdxLoad', 'echo_js_vars_from_options'));
add_action('admin_head', array('DispletRetsIdxLoad', 'echo_admin_js_vars_from_options'));

?>