<?php

/*
 * Plugin name: Displet RETS/IDX
 * Plugin URI: http://displet.com/wordpress-plugins/displetreader-wordpress-plugin
 * Description: RETS/IDX Plugin that inserts real estate listings, statistics, maps, and quick searches into Wordpress pages & widget ready sidebars. Free version available.
 * Version: 2.0.4
 * Author: Displet
 * Author URI: http://displet.com/
 * License: GPL2
 */

/*  Copyright 2011 Displet (email : dev@displet.com)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2, as 
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

abstract class DispletRetsIdxPlugin{
	protected static $plugin_version = '2.0.4';
	protected static $api_url = 'http://api.displet.com';

    public function add_version(){
        echo '<!-- Displet RETS/IDX v. ' . self::$plugin_version . ' -->';
    }

    public function register_default_settings(){
	    $has_default_page = get_page_by_path('rets');
	    if (!$has_default_page) {    
	        $displet_default_rets_idx_page = array(
	          'post_name' => 'rets',
	          'post_title' => 'Real Estate',
	          'post_type' => 'page',
	          'post_status' => 'publish'
	        );
	        wp_insert_post($displet_default_rets_idx_page);
	    }
	    $displetretsidx_option = DispletRetsIdxSettings::get_defaults();
		add_option('displet_rets_idx_options', $displetretsidx_option);
	}

	public function register_default_widgets(){
		$widgets = get_option('widget_displetretsidxsearchfield');
		if (empty($widgets[1])) {
			$widgets[1] = array(
				'title' => 'Property Type',
				'field' => 'property_type'
			);
		}
		if (empty($widgets[2])) {
			$widgets[2] = array(
				'title' => 'Price Min/Max',
				'field' => 'price'
			);
		}
		if (empty($widgets[3])) {
			$widgets[3] = array(
				'title' => 'Beds/Baths',
				'field' => 'beds_baths'
			);
		}
		if (empty($widgets[4])) {
			$widgets[4] = array(
				'title' => 'City, Zip, Neighborhood, or Condo',
				'field' => 'quick_terms'
			);
		}
		if (empty($widgets[5])) {
			$widgets[5] = array(
				'title' => 'Keywords: Ex. Pool, Modern, Foreclosure',
				'field' => 'keywords'
			);
		}
		if (empty($widgets[6])) {
			$widgets[6] = array(
				'title' => 'Foreclosure',
				'field' => 'foreclosure'
			);
		}
		if (empty($widgets[7])) {
			$widgets[7] = array(
				'title' => 'School District',
				'field' => 'school_district'
			);
		}
		if (empty($widgets[8])) {
			$widgets[8] = array(
				'title' => 'School',
				'field' => 'school'
			);
		}
		if (empty($widgets[9])) {
			$widgets[9] = array(
				'title' => 'Pool',
				'field' => 'pool'
			);
		}
		if (empty($widgets[10])) {
			$widgets[10] = array(
				'title' => 'Waterfront',
				'field' => 'waterfront'
			);
		}
		if (empty($widgets[11])) {
			$widgets[11] = array(
				'title' => 'Property Type',
				'field' => 'property_type'
			);
		}
		if (empty($widgets[12])) {
			$widgets[12] = array(
				'title' => 'Price Min/Max',
				'field' => 'price'
			);
		}
		if (empty($widgets[13])) {
			$widgets[13] = array(
				'title' => 'Beds/Baths',
				'field' => 'beds_baths'
			);
		}
		if (empty($widgets[14])) {
			$widgets[14] = array(
				'title' => 'City, Zip, Neighborhood, or Condo',
				'field' => 'quick_terms'
			);
		}
		if (empty($widgets[15])) {
			$widgets[15] = array(
				'title' => 'Keywords: Ex. Pool, Modern, Foreclosure',
				'field' => 'keywords'
			);
		}
		update_option('widget_displetretsidxsearchfield', $widgets);
	}

	public function register_default_widget_areas_content(){
		$sidebars = get_option('sidebars_widgets');
		$need_sidebars_update = false;
		if (empty($sidebars['displetretsidx-search-form-1'])) {
			$need_sidebars_update = true;
			$sidebars['displetretsidx-search-form-1'] = array(
				'displetretsidxsearchfield-1',
				'displetretsidxsearchfield-2',
				'displetretsidxsearchfield-3'
			);
			$sidebars['displetretsidx-search-form-2'] = array(
				'displetretsidxsearchfield-4',
				'displetretsidxsearchfield-5',
				'displetretsidxsearchfield-6'
			);
			$sidebars['displetretsidx-search-form-advanced-1'] = array(
				'displetretsidxsearchfield-7',
				'displetretsidxsearchfield-8'
			);
			$sidebars['displetretsidx-search-form-advanced-2'] = array(
				'displetretsidxsearchfield-9',
				'displetretsidxsearchfield-10'
			);
		}
		if (empty($sidebars['displetretsidx-quick-search-1-form-1'])) {
			$need_sidebars_update = true;
			$sidebars['displetretsidx-quick-search-1-form-1'] = array(
				'displetretsidxsearchfield-11',
				'displetretsidxsearchfield-12',
				'displetretsidxsearchfield-13',
				'displetretsidxsearchfield-14',
				'displetretsidxsearchfield-15'
			);
		}
		if ($need_sidebars_update) {
			update_option('sidebars_widgets', $sidebars);
		}
    }
}

add_action('wp_head', array('DispletRetsIdxPlugin', 'add_version'), 1000000);
register_activation_hook(__FILE__, array('DispletRetsIdxPlugin', 'register_default_settings'));
register_activation_hook(__FILE__, array('DispletRetsIdxPlugin', 'register_default_widgets'));
register_activation_hook(__FILE__, array('DispletRetsIdxPlugin', 'register_default_widget_areas_content'));
register_activation_hook(__FILE__, array('DispletRetsIdxEmails', 'adjust_activity_report_schedule'));
register_deactivation_hook(__FILE__, array('DispletRetsIdxEmails', 'unschedule_activity_report'));

require_once('displet-load.php');
require_once('displet-settings.php');
require_once('displet-query.php');
require_once('displet-emails.php');
require_once('displet-email-templates.php');
require_once('displet-google-login.php');
require_once('displet-url-structure.php');
require_once('displet-quick-start.php');
require_once('displet-search-results.php');
require_once('displet-shortcodes.php');
require_once('displet-tinymce.php');
require_once('displet-users.php');
require_once('displet-utilities.php');
require_once('displet-widgets.php');

?>