<?php
	// Get settings
	$displetretsidx_option = DispletRetsIdxSettings::get_option();

	// Determine page, query offset, and pagination URLs
	$page = !empty($_GET['pagenum']) ? intval($_GET['pagenum']) : 1;
	$offset = 25 * ($page - 1);
	$unpaged_url = preg_replace('/&pagenum=(\d+)/', '', $_SERVER["REQUEST_URI"]);
	$previous_url = $unpaged_url . '&pagenum=' . ($page - 1);
	$next_url = $unpaged_url . '&pagenum=' . ($page + 1);

	// Get users tagged as leads
	$args = array(
		'orderby' => 'registered',
		'order' => 'DESC',
		'number' => 25,
		'offset' => $offset
	);
	if ($is_admin = current_user_can('manage_options')){
		$args['meta_key'] = 'displet_lead';
		$args['meta_value'] = true;
	}
	else{
		$args['meta_key'] = 'displet_agent_id';
		$args['meta_value'] = get_current_user_id();
	}
	$leads = get_users($args);
?>
<div class="wrap displetreader leads">
	<h2>Displet Lead Manager</h2>
	<div class="pagination">
		<?php if (!empty($page) && $page != 1) : ?>
			<a href="<?php echo $previous_url; ?>" class="displet-left">Previous Page</a>
		<?php endif; ?>
		<?php if (count($leads) == 25) : ?>
			<a href="<?php echo $next_url; ?>" class="displet-right">Next Page</a>
		<?php endif; ?>
		<div class="displet-clear"><!-- --></div>
	</div>
	<table id="displet-leads">
		<tr>
			<th></th>
			<th>Name</th>
			<th>Email</th>
			<th>Phone</th>
			<?php if (!empty($displetretsidx_option['include_working_with_realtor'])) : ?>
				<th>Has Realtor</th>
			<?php endif; ?>
			<th>Price Mean</th>
			<th>Sq Ft Mean</th>
			<th>Zip Mode</th>
			<?php if ($is_admin) : ?>
				<th>Assigned To</th>
			<?php endif; ?>
		</tr>
		<?php
			if (!empty($leads)) {
				$search_results_url = get_permalink($displetretsidx_option['search_results_page_id']);
				$property_details_url = get_permalink($displetretsidx_option['property_details_page_id']);
				foreach ($leads as $lead) {
					// Newer leads stored as timestamp
					if (is_numeric($lead->displet_last_login)) {
						$lead->last_login = date('Y/m/d \a\t g:ia', $lead->displet_last_login);
					}
					// Older leads stored in date format
					else{
						$lead->last_login = $lead->displet_last_login;
					}
					$lead->edit_url = admin_url('user-edit.php?user_id=' . $lead->ID);
					if ($is_admin) {
						$assigned_agent_id = get_user_meta($lead->ID, 'displet_agent_id', true);
						if (!empty($assigned_agent_id)) {
							$assigned_agent = get_userdata(intval($assigned_agent_id));
							$assigned_to = $assigned_agent->display_name;
						}
						else{
							$assigned_to = 'Unassigned';
						}
					}
					$searches_markup = '';
					if (!empty($lead->displet_user_hashes)) {
						foreach ($lead->displet_user_hashes as $hash) {
							$searches_markup .= '<a href="' . $search_results_url . $hash . '" target="_blank">' . $search_results_url . $hash . '</a><br>';
						}
					}
					$properties_markup = '';
					if (!empty($lead->displet_user_properties)) {
						$property_stats = DispletRetsIdxUsers::get_property_view_stats($lead->displet_user_properties);
						foreach ($lead->displet_user_properties as $property) {
							if (!empty($property['url'])){
								$property['address'] = (!empty($property['address'])) ? $property['address'] : 'Property';
								$properties_markup .= '<a href="' . $property_details_url . $property['url'] . '" target="_blank">' . $property['address'] . '</a><br>';
							}
						}
					}

					if (!empty($displetretsidx_option['include_working_with_realtor'])) {
						$realtor_markup = '<td>' . $lead->displet_realtor . '</td>';
					}
					else{
						$realtor_markup = '';
					}

					echo
						'<tr class="displet-lead">
							<td><input id="' . $lead->ID . '" type="checkbox"></td>
							<td>' . $lead->display_name . ' <a href="javascript:void(0);" id="displet-lead-' . $lead->ID . '" class="displet-user">(Details)</a></td>
							<td><a href="mailto:' . $lead->user_email . '">' . $lead->user_email . '</a></td>
							<td>' . $lead->displet_phone . '</td>
							' . $realtor_markup . '
							<td>' . $property_stats['price_average'] . '</td>
							<td>' . $property_stats['square_feet_average'] . '</td>
							<td>' . $property_stats['zip_mode'] . '</td>';
					if ($is_admin) {
						$colspan = '6';
						echo 
							'<td>' . $assigned_to . '</td>';
					}
					else{
						$colspan = '5';
					}
					echo
						'</tr>
						<tr class="displet-lead-details displet-lead-' . $lead->ID . '">
							<td><!-- --></td>
							<td class="displet-edit-user">
								<a href="' . $lead->edit_url . '">Edit User</a>
							</td>
							<td colspan="' . $colspan . '">
								<table class="displet-details">
									<tr>
										<td><label>Last login:</label> ' . $lead->last_login . '</td>
										<td><label>Registered on: </label>' . get_date_from_gmt($lead->user_registered, 'Y/m/d \a\t g:ia') . '</td>
									</tr>
									<tr>
										<td class="url"><label>Registered at:</label> <a href="' . $lead->displet_registration_url . '" target="_blank">' . $lead->displet_registration_url . '</a></td>
										<td class="url"><label>Registered from:</label> <a href="' . $lead->displet_registration_upstream_url . '" target="_blank">' . $lead->displet_registration_upstream_url . '</a></td>
									</tr>
									<tr>
										<td class="url">
											<label>
												Searched for:
											</label>
											' . $searches_markup . '
										</td>
										<td class="url">
											<label>
												Viewed:
											</label>
											' . $properties_markup . '
										</td>
									</tr>
								</table>
							</td>
						</tr>';
				}
			}
			else{
				echo '<tr><td colspan="9">There are no leads at this time.</td></tr>';
			}
		?>
	</table>
	<div class="pagination">
		<?php if (!empty($page) && $page != 1) : ?>
			<a href="<?php echo $previous_url; ?>" class="displet-left">Previous Page</a>
		<?php endif; ?>
		<?php if (count($leads) == 25) : ?>
			<a href="<?php echo $next_url; ?>" class="displet-right">Next Page</a>
		<?php endif; ?>
		<div class="displet-clear"><!-- --></div>
	</div>
	<div class="delete">
		<a href="javascript:void(0);" id="displet_delete_selected_users" class="button-primary">Delete Selected Users</a>
	</div>
	<?php if ($is_admin) : ?>
		<div class="assign">
			Assign Selected Users to:
			<select id="displet_assigned_agent">
				<?php
					$admin_users_array = get_users(array('role' => 'administrator'));
					$agent_users_array = get_users(array('role' => 'displet_agent'));
					$users_array = array();
					if (!empty($admin_users_array)) {
						$users_array = array_merge($admin_users_array, $users_array);
					}
					if (!empty($agent_users_array)) {
						$users_array = array_merge($agent_users_array, $users_array);
					}
					if (!empty($users_array)) {
						foreach ($users_array as $user) {
							echo '<option value="' . $user->ID . '">' . $user->display_name . '</option>';
						}
					}
				?>
			</select>
			<a href="javascript:void(0);" id="displet_reassign_selected_users" class="button-primary">Assign</a>
		</div>
	<?php endif; ?>
	<div class="displet-response"><!-- --></div>
</div>